==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GridColumnSummaryOptionsDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { GridColumnSummaryOptionsDescriptionMetadata } from "./GridColumnSummaryOptionsDescriptionMetadata";
import { CheckboxListDescriptionModule } from "./CheckboxListDescriptionModule";
import { SummaryChooserDescriptionModule } from "./SummaryChooserDescriptionModule";
/**
 * @hidden
 */
var GridColumnSummaryOptionsDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnSummaryOptionsDescriptionModule, _super);
    function GridColumnSummaryOptionsDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnSummaryOptionsDescriptionModule.register = function (a) {
        GridColumnSummaryOptionsDescriptionMetadata.d(a);
        CheckboxListDescriptionModule.register(a);
        SummaryChooserDescriptionModule.register(a);
    };
    GridColumnSummaryOptionsDescriptionModule.$t = markType(GridColumnSummaryOptionsDescriptionModule, 'GridColumnSummaryOptionsDescriptionModule');
    return GridColumnSummaryOptionsDescriptionModule;
}(Base));
export { GridColumnSummaryOptionsDescriptionModule };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/GridColumnSummaryOptionsDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { GridColumnSummaryOptionsDescriptionMetadata } from "./GridColumnSummaryOptionsDescriptionMetadata";
import { CheckboxListDescriptionModule } from "./CheckboxListDescriptionModule";
import { SummaryChooserDescriptionModule } from "./SummaryChooserDescriptionModule";
/**
 * @hidden
 */
var GridColumnSummaryOptionsDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnSummaryOptionsDescriptionModule, _super);
    function GridColumnSummaryOptionsDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnSummaryOptionsDescriptionModule.register = function (a) {
        GridColumnSummaryOptionsDescriptionMetadata.d(a);
        CheckboxListDescriptionModule.register(a);
        SummaryChooserDescriptionModule.register(a);
    };
    GridColumnSummaryOptionsDescriptionModule.$t = markType(GridColumnSummaryOptionsDescriptionModule, 'GridColumnSummaryOptionsDescriptionModule');
    return GridColumnSummaryOptionsDescriptionModule;
}(Base));
export { GridColumnSummaryOptionsDescriptionModule };
